"use strict";
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.addFilter = void 0;
const FilterUtils_1 = require("../FilterUtils");
const EndevorFilter_1 = require("../model/EndevorFilter");
const EndevorController_1 = require("../EndevorController");
const vscode = require("vscode");
function addFilter(arg) {
    //If it came from a type node prefil it.
    let filterString = '';
    if (arg.contextValue === 'type') {
        filterString = arg.qualifier.env + '/' + arg.qualifier.stage + '/' + arg.qualifier.system + '/' + arg.qualifier.subsystem + '/' + arg.qualifier.type + '/*';
    }
    let inputBoxOptions = {
        value: filterString,
        prompt: "Create a new Endevor filter.",
        placeHolder: "env/stgnum/sys/subsys/type/element",
        ignoreFocusOut: true,
        validateInput(value) {
            return FilterUtils_1.filterStringValidator(arg.getRepository(), value);
        }
    };
    vscode.window.showInputBox(inputBoxOptions).then(filterUri => {
        if (filterUri) {
            const repo = arg.getRepository();
            repo.filters.push(new EndevorFilter_1.EndevorFilter(repo, filterUri));
            EndevorController_1.EndevorController.instance.updateSettings();
        }
    });
}
exports.addFilter = addFilter;
//# sourceMappingURL=AddFilter.js.map