"use strict";
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.browseElement = void 0;
const vscode = require("vscode");
const EndevorCliProxy_1 = require("../service/EndevorCliProxy");
const globals_1 = require("../globals");
function browseElement(arg) {
    return __awaiter(this, void 0, void 0, function* () {
        const repo = arg.getRepository();
        const elementName = arg.label;
        const eq = arg.getQualifier();
        vscode.window.withProgress({
            location: vscode.ProgressLocation.Notification,
            title: `Loading: ${elementName}...`,
        }, (progress) => __awaiter(this, void 0, void 0, function* () {
            progress.report({ increment: 10 });
            try {
                const data = yield EndevorCliProxy_1.proxyBrowseElement(repo, eq);
                progress.report({ increment: 50 });
                let doc;
                doc = yield vscode.workspace.openTextDocument({ content: data });
                progress.report({ increment: 100 });
                return vscode.window.showTextDocument(doc, { preview: false });
            }
            catch (error) {
                if (!error.cancelled) {
                    globals_1.logger.error(error.error);
                }
            }
        }));
    });
}
exports.browseElement = browseElement;
//# sourceMappingURL=BrowseElement.js.map