"use strict";
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.retrieveElement = void 0;
const vscode = require("vscode");
const utils_1 = require("../utils");
const globals_1 = require("../globals");
function retrieveElement(arg, selection, retrieveElementService) {
    vscode.window.withProgress({
        cancellable: true,
        location: vscode.ProgressLocation.Notification,
        title: "Retrieving element",
    }, (progress, token) => __awaiter(this, void 0, void 0, function* () {
        token.onCancellationRequested(() => {
            globals_1.logger.info("Retrieve Cancelled.");
        });
        const processedSelection = utils_1.prepareElementNodesForRetrieve(selection);
        if (processedSelection.length === 0) {
            processedSelection.push(arg);
        }
        const incrementNumber = 100 / processedSelection.length;
        if (!(vscode.workspace.workspaceFolders && vscode.workspace.workspaceFolders.length > 0)) {
            globals_1.logger.error("Specify workspace before retrieving elements");
            return;
        }
        const workspace = vscode.workspace.workspaceFolders[0];
        for (let i = 0; i < processedSelection.length; i++) {
            if (token.isCancellationRequested) {
                return;
            }
            const currentElement = processedSelection[i];
            const repo = currentElement.getRepository();
            const elementName = currentElement.label;
            const eq = currentElement.getQualifier();
            if (!(repo && elementName && eq)) {
                throw new Error(JSON.stringify({ repo, elementName, eq }));
            }
            try {
                progress.report({
                    message: `(${i + 1}/${processedSelection.length}) ${elementName}`,
                });
                const filePath = yield retrieveElementService.retrieveElement(workspace, repo, elementName, eq);
                const doc = yield vscode.workspace.openTextDocument(filePath);
                vscode.window.showTextDocument(doc, { preview: false });
                progress.report({
                    increment: incrementNumber,
                    message: `(${i + 1}/${processedSelection.length}) ${elementName}`,
                });
            }
            catch (error) {
                retrieveElementService.processRetrieveElementError(error);
            }
        }
    }));
}
exports.retrieveElement = retrieveElement;
//# sourceMappingURL=RetrieveElement.js.map