"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.make = void 0;
const vscode = require("vscode");
const constants_1 = require("./constants");
const typeHelpers_1 = require("./typeHelpers");
var LOGEVEL;
(function (LOGEVEL) {
    LOGEVEL[LOGEVEL["TRACE"] = 0] = "TRACE";
    LOGEVEL[LOGEVEL["INFO"] = 1] = "INFO";
    LOGEVEL[LOGEVEL["WARN"] = 2] = "WARN";
    LOGEVEL[LOGEVEL["ERROR"] = 3] = "ERROR";
})(LOGEVEL || (LOGEVEL = {}));
const format = (userMsg, logMsg) => logMsg
    ? `${userMsg} (see OUTPUT - ${constants_1.OUTPUT_CHANNEL_NAME} for more details)`
    : userMsg;
const logAndDisplay = (outputChannel) => (lvl) => (userMsg, logMsg) => {
    outputChannel.appendLine(userMsg);
    outputChannel.appendLine(logMsg !== null && logMsg !== void 0 ? logMsg : "(no detail message)");
    switch (lvl) {
        case LOGEVEL.TRACE:
            break;
        case LOGEVEL.INFO:
            vscode.window.showInformationMessage(format(userMsg, logMsg));
            break;
        case LOGEVEL.WARN:
            vscode.window.showWarningMessage(format(userMsg, logMsg));
            break;
        case LOGEVEL.ERROR:
            vscode.window.showErrorMessage(format(userMsg, logMsg));
            break;
        default:
            throw new typeHelpers_1.UnreachableCaseError(lvl);
    }
};
exports.make = (outputChannel) => {
    const log = logAndDisplay(outputChannel);
    return {
        trace: (msg) => log(LOGEVEL.TRACE)(msg),
        info: log(LOGEVEL.INFO),
        warn: log(LOGEVEL.WARN),
        error: log(LOGEVEL.ERROR),
    };
};
//# sourceMappingURL=logger.js.map