"use strict";
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Connection = void 0;
const EndevorEntity_1 = require("./EndevorEntity");
class Connection extends EndevorEntity_1.EndevorEntity {
    constructor(profile) {
        super();
        this.message = profile.message;
        this.type = profile.type;
        this.failNotFound = profile.failNotFound;
        this.name = profile.name;
        this.referencedBy = profile.referencedBy;
        this.profile = profile.profile;
        this.dependenciesLoaded = profile.dependenciesLoaded;
        this.dependencyLoadResponses = profile.dependencyLoadResponses;
        this._repositories = new Map();
    }
    loadRepository(repo) {
        this._repositories.set(repo.getName(), repo);
    }
    findRepository(repoName) {
        return this._repositories.get(repoName);
    }
    getRepository() {
        throw new Error("Method not implemented.");
    }
    getRepositoryMap() {
        return this._repositories;
    }
    getRepositoryList() {
        return Array.from(this._repositories.values());
    }
    setRepositoryList(repos) {
        repos.forEach(repo => {
            this._repositories.set(repo.getName(), repo);
        });
    }
    get repositories() {
        return this._repositories;
    }
    set repositories(repoMap) {
        this._repositories = repoMap;
    }
    getConnection() {
        return this;
    }
    getName() {
        return this.name;
    }
    getDescription() {
        return "";
    }
    getProfile() {
        return this.profile;
    }
}
exports.Connection = Connection;
//# sourceMappingURL=Connection.js.map