"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.proxyListSystem = exports.proxyListSubsystem = exports.proxyListStage = exports.proxyListEnvironment = exports.proxyListElement = exports.proxyListType = exports.proxyRetrieveAcmComponents = exports.proxyRetrieveElement = exports.proxyGetDsNamesFromInstance = exports.proxyBrowseElement = void 0;
const endevor_for_zowe_cli_1 = require("@broadcom/endevor-for-zowe-cli");
const utils_1 = require("../utils");
const globals_1 = require("../globals");
function proxyBrowseElement(repository, endevorQualifier) {
    return __awaiter(this, void 0, void 0, function* () {
        const session = yield utils_1.buildSession(repository);
        const element = utils_1.endevorQualifierToElement(endevorQualifier, repository.getDatasource());
        const requestBody = endevor_for_zowe_cli_1.PrintElementComponents.setupPrintRequest({});
        const printResult = yield endevor_for_zowe_cli_1.PrintElementComponents.printElementComponents(session, element, requestBody);
        return printResult.data ? printResult.data.toString() : undefined;
    });
}
exports.proxyBrowseElement = proxyBrowseElement;
function proxyGetDsNamesFromInstance(repository) {
    return __awaiter(this, void 0, void 0, function* () {
        const session = yield utils_1.buildSession(repository);
        const dataSources = yield endevor_for_zowe_cli_1.ListInstance.listInstance(session);
        return dataSources
            .map(ds => ds.name)
            .sort();
    });
}
exports.proxyGetDsNamesFromInstance = proxyGetDsNamesFromInstance;
function proxyRetrieveElement(repository, endevorQualifier) {
    return __awaiter(this, void 0, void 0, function* () {
        const session = yield utils_1.buildSession(repository);
        const element = utils_1.endevorQualifierToElement(endevorQualifier, repository.getDatasource());
        const requestArgs = {
            nosignout: "yes",
        };
        const requestBody = endevor_for_zowe_cli_1.RetrieveElement.setupRetrieveRequest(requestArgs);
        const retrieveResult = yield endevor_for_zowe_cli_1.RetrieveElement.retrieveElement(session, element, requestBody);
        return retrieveResult.data ? retrieveResult.data.toString() : undefined;
    });
}
exports.proxyRetrieveElement = proxyRetrieveElement;
function proxyRetrieveAcmComponents(repository, endevorQualifier) {
    return __awaiter(this, void 0, void 0, function* () {
        const session = yield utils_1.buildSession(repository);
        const instance = repository.getDatasource();
        const endevorElement = utils_1.endevorQualifierToElement(endevorQualifier, instance);
        const requestArguments = {
            excCirculars: "yes",
            excIndirect: "no",
            excRelated: "no",
        };
        const requestBody = endevor_for_zowe_cli_1.QueryACMComponents.setupAcmComponentsRequest(requestArguments);
        const queryacmCompResponse = yield endevor_for_zowe_cli_1.QueryACMComponents.queryACMComponents(session, instance, endevorElement, requestBody);
        return queryacmCompResponse.data;
    });
}
exports.proxyRetrieveAcmComponents = proxyRetrieveAcmComponents;
function proxyListType(repository, endevorQualifier) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        const session = yield utils_1.buildSession(repository);
        const instance = repository.getDatasource();
        const typeInput = utils_1.endevorQualifierToElement(endevorQualifier, instance);
        const requestBody = endevor_for_zowe_cli_1.ListType.setupListTypeRequest({});
        const listResponse = yield endevor_for_zowe_cli_1.ListType.listType(session, instance, typeInput, requestBody);
        if (listResponse.returnCode > 0) {
            globals_1.logger.error(listResponse.messages ? (_a = listResponse.messages[1]) !== null && _a !== void 0 ? _a : listResponse.messages[0] : "Error retrieving element type", (_b = listResponse.messages) === null || _b === void 0 ? void 0 : _b.toString());
        }
        return utils_1.toArray(listResponse.data);
    });
}
exports.proxyListType = proxyListType;
function proxyListElement(repository, endevorQualifier) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        const session = yield utils_1.buildSession(repository);
        const instance = repository.getDatasource();
        const endevorElement = utils_1.endevorQualifierToElement(endevorQualifier, instance);
        const requestBody = endevor_for_zowe_cli_1.ListElement.setupListElementRequest({});
        const listResponse = yield endevor_for_zowe_cli_1.ListElement.listElement(session, instance, endevorElement, requestBody);
        if (listResponse.returnCode > 0) {
            globals_1.logger.error(listResponse.messages ? (_a = listResponse.messages[1]) !== null && _a !== void 0 ? _a : listResponse.messages[0] : "Error retrieving element", (_b = listResponse.messages) === null || _b === void 0 ? void 0 : _b.toString());
        }
        return utils_1.toArray(listResponse.data);
    });
}
exports.proxyListElement = proxyListElement;
function proxyListEnvironment(repository) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        const session = yield utils_1.buildSession(repository);
        const instance = repository.getDatasource();
        const environment = utils_1.endevorQualifierToElement({}, instance);
        const requestBody = endevor_for_zowe_cli_1.ListEnvironment.setupListEnvironmentRequest({});
        const envResponse = yield endevor_for_zowe_cli_1.ListEnvironment.listEnvironment(session, instance, environment, requestBody);
        if (envResponse.returnCode > 0) {
            globals_1.logger.error(envResponse.messages ? (_a = envResponse.messages[1]) !== null && _a !== void 0 ? _a : envResponse.messages[0] : "Error retrieving environment", (_b = envResponse.messages) === null || _b === void 0 ? void 0 : _b.toString());
        }
        return utils_1.toArray(envResponse.data);
    });
}
exports.proxyListEnvironment = proxyListEnvironment;
function proxyListStage(repository, endevorQualifier) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        const session = yield utils_1.buildSession(repository);
        const instance = repository.getDatasource();
        const stageNumber = utils_1.endevorQualifierToElement(endevorQualifier, instance);
        const requestBody = endevor_for_zowe_cli_1.ListStage.setupListStageRequest({});
        const listResponse = yield endevor_for_zowe_cli_1.ListStage.listStage(session, instance, stageNumber, requestBody);
        if (listResponse.returnCode > 0) {
            globals_1.logger.error(listResponse.messages ? (_a = listResponse.messages[1]) !== null && _a !== void 0 ? _a : listResponse.messages[0] : "Error retrieving stage", (_b = listResponse.messages) === null || _b === void 0 ? void 0 : _b.toString());
        }
        return utils_1.toArray(listResponse.data);
    });
}
exports.proxyListStage = proxyListStage;
function proxyListSubsystem(repository, endevorQualifier) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        const session = yield utils_1.buildSession(repository);
        const instance = repository.getDatasource();
        const endevorSubsystem = utils_1.endevorQualifierToElement(endevorQualifier, instance);
        const requestBody = endevor_for_zowe_cli_1.ListSubsystem.setupListSubsystemRequest({});
        const listSubsystemResponse = yield endevor_for_zowe_cli_1.ListSubsystem.listSubsystem(session, instance, endevorSubsystem, requestBody);
        if (listSubsystemResponse.returnCode > 0) {
            globals_1.logger.error(listSubsystemResponse.messages ? (_a = listSubsystemResponse.messages[1]) !== null && _a !== void 0 ? _a : listSubsystemResponse.messages[0] : "Error retrieving subsystem", (_b = listSubsystemResponse.messages) === null || _b === void 0 ? void 0 : _b.toString());
        }
        return utils_1.toArray(listSubsystemResponse.data);
    });
}
exports.proxyListSubsystem = proxyListSubsystem;
function proxyListSystem(repository, endevorQualifier) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        const session = yield utils_1.buildSession(repository);
        const instance = repository.getDatasource();
        const endevorSystem = utils_1.endevorQualifierToElement(endevorQualifier, instance);
        const requestBody = endevor_for_zowe_cli_1.ListSystem.setupListSystemRequest({});
        const listSystemResponse = yield endevor_for_zowe_cli_1.ListSystem.listSystem(session, instance, endevorSystem, requestBody);
        if (listSystemResponse.returnCode > 0) {
            globals_1.logger.error(listSystemResponse.messages ? (_a = listSystemResponse.messages[1]) !== null && _a !== void 0 ? _a : listSystemResponse.messages[0] : "Error retrieving subsystem", (_b = listSystemResponse.messages) === null || _b === void 0 ? void 0 : _b.toString());
        }
        return utils_1.toArray(listSystemResponse.data);
    });
}
exports.proxyListSystem = proxyListSystem;
//# sourceMappingURL=EndevorCliProxy.js.map