"use strict";
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SettingsFacade = exports.HOST_SETTINGS_KEY = void 0;
const vscode = require("vscode");
const EndevorFilter_1 = require("../model/EndevorFilter");
const Repository_1 = require("../model/Repository");
const Profiles_1 = require("./Profiles");
const globals_1 = require("../globals");
exports.HOST_SETTINGS_KEY = "endevor.connections";
class SettingsFacade {
    static listConnections() {
        return vscode.workspace.getConfiguration().get(exports.HOST_SETTINGS_KEY, []);
    }
    static listRepositories(connectionLabel) {
        const repos = [];
        // tslint:disable-next-line: max-line-length
        const allConnectionsInSettings = vscode.workspace.getConfiguration().get(exports.HOST_SETTINGS_KEY, []);
        const connectionInSettings = allConnectionsInSettings.find(connection => connection.name === connectionLabel);
        const hosts = connectionInSettings ? connectionInSettings.hosts : [];
        const profile = Profiles_1.Profiles.getInstance().loadNamedProfile(connectionLabel).profile;
        if (profile) {
            hosts.forEach(host => {
                const repo = new Repository_1.Repository(host.name, `${profile.protocol}://${profile.host}:${profile.port}`, profile.user, profile.password, host.datasource, host.profileLabel, host.id);
                if (host.filters) {
                    const newFilters = new Map();
                    host.filters.forEach(filter => {
                        newFilters.set(filter.uri, new EndevorFilter_1.EndevorFilter(repo, filter.uri));
                        repo.filters.push(new EndevorFilter_1.EndevorFilter(repo, filter.uri));
                    });
                    repo.filters = Array.from(newFilters.values());
                }
                repos.push(repo);
            });
        }
        return repos;
    }
    static updateSettings(connections) {
        return __awaiter(this, void 0, void 0, function* () {
            const conns = [];
            connections.forEach(connection => {
                const hostsArray = [];
                const toPush = {
                    name: connection.getName(),
                    // tslint:disable-next-line: object-literal-sort-keys
                    hosts: hostsArray
                };
                connection.getRepositoryList().forEach(repo => {
                    toPush.hosts.push({
                        datasource: repo.getDatasource(),
                        filters: repo.getIFilters(),
                        id: repo.id,
                        name: repo.getName(),
                        profileLabel: repo.getProfileLabel(),
                        url: repo.getUrl(),
                        username: repo.getUsername(),
                    });
                });
                conns.push(toPush);
            });
            try {
                yield vscode.workspace.getConfiguration().update(exports.HOST_SETTINGS_KEY, conns, vscode.ConfigurationTarget.Global);
            }
            catch (error) {
                globals_1.logger.error("Error saving to settings.", error);
            }
        });
    }
    static updateRepositories(connection) {
        return __awaiter(this, void 0, void 0, function* () {
            const repos = connection.getRepositoryList();
            const hosts = [];
            repos.forEach(repo => {
                hosts.push({
                    datasource: repo.getDatasource(),
                    filters: repo.getIFilters(),
                    id: repo.id,
                    name: repo.getName(),
                    profileLabel: repo.getProfileLabel(),
                    url: repo.getUrl(),
                    username: repo.getUsername()
                });
            });
            const value = {
                "endevor.hosts": hosts,
            };
            try {
                yield vscode.workspace.getConfiguration().update(exports.HOST_SETTINGS_KEY, value, vscode.ConfigurationTarget.Global);
            }
            catch (error) {
                globals_1.logger.error("Error saving to settings.", error);
            }
        });
    }
}
exports.SettingsFacade = SettingsFacade;
//# sourceMappingURL=SettingsFacade.js.map