"use strict";
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CredentialsInputBox = void 0;
const vscode = require("vscode");
const EndevorController_1 = require("../../EndevorController");
class CredentialsInputBox {
    /**
     * Ask credentions.
     * @param repo repository
     * @returns object with username and password attrinbutes of undefined if canceled.
     */
    static askforCredentials(repo) {
        return __awaiter(this, void 0, void 0, function* () {
            const username = yield CredentialsInputBox.showUserName(repo.getUsername());
            if (username === undefined) {
                return undefined;
            }
            const password = yield CredentialsInputBox.showPasswordBox();
            if (password === undefined) {
                return undefined;
            }
            repo.setUsername(username);
            repo.setPassword(password);
            EndevorController_1.EndevorController.instance.updateSettings();
            return { password, username };
        });
    }
    static showUserName(username) {
        return __awaiter(this, void 0, void 0, function* () {
            username = username ? username : "";
            return vscode.window.showInputBox({
                ignoreFocusOut: true,
                placeHolder: "Username",
                prompt: "Enter the Username ",
                validateInput: (text) => (text !== "" ? "" : "Username must not be empty"),
                value: username
            });
        });
    }
    static showPasswordBox() {
        return __awaiter(this, void 0, void 0, function* () {
            return vscode.window.showInputBox({
                ignoreFocusOut: true,
                password: true,
                placeHolder: "Mainframe password",
                prompt: "Enter the password ",
                validateInput: (text) => (text !== "" ? "" : "Password must not be empty"),
            });
        });
    }
}
exports.CredentialsInputBox = CredentialsInputBox;
//# sourceMappingURL=CredentialsInput.js.map