"use strict";
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.endevorQualifierToElement = exports.buildSession = exports.multipleElementsSelected = exports.prepareElementNodesForRetrieve = exports.constructFilterUri = exports.constructFilterName = exports.toArray = exports.FilterDescriptor = exports.FilterItem = exports.resolveQuickPickHelper = void 0;
const imperative_1 = require("@zowe/imperative");
const CredentialsInput_1 = require("./ui/tree/CredentialsInput");
const EndevorNodes_1 = require("./ui/tree/EndevorNodes");
const globals_1 = require("./globals");
function resolveQuickPickHelper(quickpick) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((c) => quickpick.onDidAccept(() => c(quickpick.activeItems[0])));
    });
}
exports.resolveQuickPickHelper = resolveQuickPickHelper;
// tslint:disable-next-line: max-classes-per-file
class FilterItem {
    constructor(text) {
        this.text = text;
    }
    get label() {
        return this.text;
    }
    get description() {
        return "";
    }
    get alwaysShow() {
        return false;
    }
}
exports.FilterItem = FilterItem;
// tslint:disable-next-line: max-classes-per-file
class FilterDescriptor {
    constructor(text) {
        this.text = text;
    }
    get label() {
        return this.text;
    }
    get description() {
        return "";
    }
    get alwaysShow() {
        return true;
    }
}
exports.FilterDescriptor = FilterDescriptor;
function toArray(data) {
    if (Array.isArray(data)) {
        return data;
    }
    else if (data) {
        return [data];
    }
    else {
        return [];
    }
}
exports.toArray = toArray;
function constructFilterName(uri) {
    let name = "";
    const splitString = uri.split("/");
    splitString.forEach((member) => {
        if (!(member === "env" ||
            member === "stgnum" ||
            member === "sys" ||
            member === "subsys" ||
            member === "type" ||
            member === "ele")) {
            name = name + "/" + member;
        }
    });
    return name.replace("//", "/");
}
exports.constructFilterName = constructFilterName;
function constructFilterUri(uri) {
    const uriFormatted = "";
    return uriFormatted;
}
exports.constructFilterUri = constructFilterUri;
function prepareElementNodesForRetrieve(selection) {
    const selectedElementNodes = [];
    for (let i = 0; i < selection.length; i++) {
        if (selection[i] instanceof EndevorNodes_1.EndevorElementNode) {
            selectedElementNodes.push(selection[i]);
        }
    }
    return selectedElementNodes;
}
exports.prepareElementNodesForRetrieve = prepareElementNodesForRetrieve;
function multipleElementsSelected(selection) {
    if (selection.length > 1) {
        return true;
    }
    else {
        return false;
    }
}
exports.multipleElementsSelected = multipleElementsSelected;
function getBasePathFromRepo(repository) {
    return (repository.getUrlString().split(":")[2].split("/")[1] +
        "/" +
        repository.getUrlString().split(":")[2].split("/")[2]);
}
function buildSession(repository) {
    return __awaiter(this, void 0, void 0, function* () {
        // hacky solution to make ISession happy
        globals_1.logger.trace("Building the session.");
        const protocol = repository.getUrl().split(":")[0];
        const hostname = repository.getUrl().split(":")[1].split("/")[2];
        const port = Number(repository.getUrl().split(":")[2]);
        const basePath = getBasePathFromRepo(repository);
        if (!repository.getPassword()) {
            globals_1.logger.trace("Password not received. Prompting.");
            const creds = yield CredentialsInput_1.CredentialsInputBox.askforCredentials(repository);
            if (!creds) {
                globals_1.logger.trace("Password not provided. Cancelling.");
                throw { cancelled: true };
            }
        }
        const sessionDetails = {
            base64EncodedAuth: Buffer.from(repository.getUsername() + ":" + repository.getPassword()).toString("base64"),
            basePath,
            hostname,
            port,
            protocol,
            rejectUnauthorized: false,
            type: "basic",
        };
        const session = new imperative_1.Session(sessionDetails);
        globals_1.logger.trace(`Session created. ${JSON.stringify(session)}`);
        return session;
    });
}
exports.buildSession = buildSession;
function endevorQualifierToElement(endevorQualifier, instance) {
    return {
        element: endevorQualifier.element ? endevorQualifier.element : "*",
        environment: endevorQualifier.env ? endevorQualifier.env : "*",
        instance,
        stageNumber: endevorQualifier.stage ? endevorQualifier.stage : "*",
        subsystem: endevorQualifier.subsystem
            ? endevorQualifier.subsystem
            : "*",
        system: endevorQualifier.system ? endevorQualifier.system : "*",
        type: endevorQualifier.type ? endevorQualifier.type : "*",
    };
}
exports.endevorQualifierToElement = endevorQualifierToElement;
//# sourceMappingURL=utils.js.map